@@ -8,9 +8,9 @@ from gitdown.config import  github_access_token
 def download_file(repo, path, dst):
     print('Download {0} now!'.format(path))
     sys.stdout.flush()
-    
+
     if os.path.exists(os.path.dirname(dst)) == False:
-        os.makedirs(os.path.dirname(dst), True)
+        os.makedirs(os.path.dirname(dst), exist_ok=True)
 
     url='https://api.github.com/repos/{0}/contents/{1}'.format(repo, path)
     headers = {
@@ -18,8 +18,9 @@ def download_file(repo, path, dst):
         'Authorization':'token {0}'.format(github_access_token)
     }
     get = requests.get(url, headers = headers)
+    content = base64.b64decode(get.json()['content']).decode()
     with open(dst,'w') as fp:
-        fp.write(base64.b64decode(get.json()['content']).decode())
+        fp.write(content)
     return  get.status_code
 
 if __name__ == '__main__':
