@@ -5,7 +5,7 @@ from gitdown import download
 import tqdm
 import os
 import threading
-
+import time
 
 lock = threading.Semaphore(1)
 files = []
@@ -26,6 +26,7 @@ def down(repo, file):
         lock.acquire()
         files.append(file)
         lock.release()
+        time.sleep(10)
 
     sem.release()
 
